==> haskell-cheapskate-0.1.1.1-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1.1
id: cheapskate-0.1.1.1-4Yvmhz7YhqZ8sURjiHeTJM
key: cheapskate-0.1.1.1-4Yvmhz7YhqZ8sURjiHeTJM
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: f918acf9ceb49ff01eb708d5a4dc78ca
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cheapskate-0.1.1.1
hs-libraries: HScheapskate-0.1.1.1-4Yvmhz7YhqZ8sURjiHeTJM
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    containers-0.6.0.1 data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    text-1.2.3.1 uniplate-1.6.12-7fX2pszesPEJHGunSovUCw
    xss-sanitize-0.3.6-HPOU2VrQpzI1pLCsRioqAJ
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.1-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.1.1
id: cheapskate-0.1.1.1-6cWTNpmUcu7DVII0lFKA9W
key: cheapskate-0.1.1.1-6cWTNpmUcu7DVII0lFKA9W
license: BSD-3-Clause
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
abi: 88105049f27b54b714b17513a6047c3e
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
import-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cheapskate-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cheapskate-0.1.1.1
hs-libraries: HScheapskate-0.1.1.1-6cWTNpmUcu7DVII0lFKA9W
depends:
    base-4.12.0.0 blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    containers-0.6.0.1 data-default-0.7.1.1-GQk9Hqcpzml6dpaWfistUm
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    text-1.2.3.1 uniplate-1.6.12-5gyarWXtjl1Bv6UVRDonFe
    xss-sanitize-0.3.6-HPOU2VrQpzI1pLCsRioqAJ
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
